@@ -410,7 +410,7 @@ int handleserverdata()
 {
 	int cont;
 	int i;
-	char chars[2];
+	char ch;
 	char stringbuffer[READ_BUFFER_LENGTH + 1];
         char pong[STRINGLEN + 1];
         size_t br;
@@ -421,22 +421,19 @@ int handleserverdata()
 	i = 0;
 	cont = 1;
         do {
-                if((br = read(mystate->sockfd, chars, 1)) < 0) {
+                if((br = read(mystate->sockfd, &ch, 1)) < 0) {
 			/* error while reading from server socket */
 #ifdef DEBUG
 			oer_debug(OER_DEBUG_ERROR, "handleserverdata->read failed: %s\n", strerror(errno));
 #endif
 			return OER_HANDLESERVERDATA_ERR_READ;
-                }
-		if(br == 0) {
-			/* nothing/eof was returned, bail out */
+                } else if(br == 0) {
+			/* nothing or EOF was returned, bail out */
 			cont = 0;
-		}
-		if(br > 0 && i < READ_BUFFER_LENGTH) {
+		} else if(br > 0 && i < READ_BUFFER_LENGTH) {
+			stringbuffer[i++] = ch;
 			/* check for newline */
-			chars[1] = '\0';
-			stringbuffer[i++] = chars[0];
-			if(chars[0] == '\n') {
+			if(ch == '\n') {
 				cont = 0;
 			}
 		}
@@ -551,8 +548,11 @@ int processactions(struct timed *t)
 {
 	struct channel *this;
 #ifdef DEBUG
-        oer_debug(OER_DEBUG_FLOOD, "processactions(\"%lu\")\n", t->at);
-        oer_debug(OER_DEBUG_INFO, "processactions->last action at %lu / delta %d / barrier %d\n", mystate->last_action.ts, (int) (mystate->now - mystate->last_action.ts), mystate->last_action.barrier);
+	/* prevent initial flooding of the console */
+	if((mystate->now - mystate->current_server->linkup) >= 10) {
+		oer_debug(OER_DEBUG_FLOOD, "processactions(\"%lu\")\n", t->at);
+		oer_debug(OER_DEBUG_INFO, "processactions->last action at %lu / delta %d / barrier %d\n", mystate->last_action.ts, (int) (mystate->now - mystate->last_action.ts), mystate->last_action.barrier);
+	}
 #endif
 	if(t->type != OER_TIMED_TYPE_KICK) {
 		if(t->prio == OER_TIMED_PRIORITY_CHANNEL_HANDLING ||
@@ -585,7 +585,7 @@ int processactions(struct timed *t)
 		break;
 	case OER_TIMED_PRIORITY_NOTICE:
 	case OER_TIMED_PRIORITY_PRIVMSG:
-		mystate->last_action.barrier += 2 + (strlen(t->command) / 50);
+		mystate->last_action.barrier += 1 + (strlen(t->command) / 50);
 		break;
 	case OER_TIMED_PRIORITY_NORMAL:
 	case OER_TIMED_PRIORITY_CHANNEL_HANDLING:
