@@ -317,7 +317,7 @@ void parseirc(char *serveroutput)
 #endif
 		return;
 	}
-	if(!strcasecmp(command, "433")) {
+	if(!strcasecmp(command, "432") || !strcasecmp(command, "433")) {
 		restpos = 0;
 		if((restpos = parse(restptr, restpos, " ", nick, NICKLEN, 0)) < 0) {
 			return;
@@ -529,6 +529,9 @@ void parseirc(char *serveroutput)
 			if(!gettobek(this, nick) && checkforbadnick(this, nick, userhost)) {
 				changetobek(this, nick, 1);
 			}
+			if(!gettobek(this, nick) && haschanflags(this, "V") && isopa(userhost)) {
+				mmode_new(this, mystate->now, "+v", nick);
+			}
 			if(!gettobek(this, nick) && haschanflags(this, "v") && isvoice(this, userhost)) {
 				mmode_new(this, mystate->now, "+v", nick);
 			}
@@ -567,6 +570,9 @@ void parseirc(char *serveroutput)
 		if(getrandommsg(this, nick2, NICKLEN, getrandom(msgcount), outstring2, HUGESTRINGLEN) < 0) {
 			return;
 		}
+		if(!isgoodquote(outstring2)) {
+			return;
+		}
 		gettimeofday(&tv2, NULL);
 		snprintf(outstring3, HUGESTRINGLEN, "\"%s\" (c) %s", outstring2, nick2);
 		sendreply(channel, 1, 0, OER_TIMED_PRIORITY_NORMAL, outstring3);
@@ -1070,6 +1076,9 @@ void parsemsg(char *nick, char *userhost, char *target, char *message)
 	if(this->i_am_op && checkforbadword(this, nick, userhost, message)) {
 		return;
 	}
+	if(this->i_am_op && checkforaction(this, nick, userhost, ctcp)) {
+		return;
+	}
 	/* only add this consequetive line iff the user
 	   isn't being kicked already (lag between kick and last message) */
 	if(!gettobek(this, nick)) {
@@ -1151,6 +1160,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 	char topic[TOPICLEN + 1];
 	char uptimestring[STRINGLEN + 1];
 	char modeline[CHANLEN + 1];
+	char ts[TINYSTRINGLEN + 1];
 	char *restptr;
 	struct channel *this;
 	struct channel *that;
@@ -1170,7 +1180,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
         }
 	tochan = (isme(target)) ? 0 : 1;
 	if(!tochan) {
-		if(!strlen(outstring) || outstring[0] != '#') {
+		if(!isvalidchannel(outstring)) {
 			/* no channel given, continue from here */
 			strncpy(channel, "<NONE>", CHANLEN);
 			restptr = commandline + prevppos;
@@ -2372,7 +2382,36 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
                         return;
                 }
                 secondstostring(mystate->now - mystate->current_server->linkup, uptimestring, STRINGLEN);
-                snprintf(outstring, WRITE_BUFFER_LENGTH, "RX/TX bytes: %d/%d, link connected for %s", mystate->current_server->rx, mystate->current_server->tx, uptimestring);
+                snprintf(outstring, WRITE_BUFFER_LENGTH, "%s RX/TX bytes: %d/%d, link connected for %s", mystate->current_server->serverhost, mystate->current_server->rx, mystate->current_server->tx, uptimestring);
+                sendreply((tochan) ? channel : nick, tochan, 0, OER_TIMED_PRIORITY_NORMAL, outstring);
+                return;
+	case OER_WHICHCOMMAND_DATE:
+#ifdef DEBUG
+                oer_debug(OER_DEBUG_INFO, "parsecommand->DATE\n");
+#endif
+		/* may be NULL */
+		this = getchptr(channel);
+                proceed = (isopa(userhost)) ? 1 : 0;
+                for(that = mystate->channels; that != NULL && !proceed; that = that->next) {
+                        if(haschanflags(that, "U") && !isatleastop(that, nick, userhost)) {
+                                continue;
+                        }
+                        if(isatleastopnow(that, nick, userhost)) {
+                                proceed = 1;
+                        }
+                }
+		/* check if message was sent to a channel and if it was
+		   is "s" flag set */
+		if(tochan && haschanflags(this, "s")) {
+			proceed = 1;
+		}
+                if(!proceed) {
+                        return;
+                }
+		strncpy(ts, ctime(&mystate->now), TINYSTRINGLEN);
+                striplf(ts);
+                tzset();
+                snprintf(outstring, WRITE_BUFFER_LENGTH, "my date is %s %s %s", ts, tzname[0], tzname[1]);
                 sendreply((tochan) ? channel : nick, tochan, 0, OER_TIMED_PRIORITY_NORMAL, outstring);
                 return;
         case OER_WHICHCOMMAND_INVALID:
